"""
numeric.py

Formatting tools for arrays
"""
from formatters import __formatters__, encode

import Numeric


# Formatter for Python Imaging Library Image objects.

def format_array(a, **kwargs):

    # Find the shape of the array.
    shape = Numeric.shape(a)
    
    # Find the number of elements in the array along the first axis.
    n = shape[0]
    
    output = ['<table border="1" cellpadding="4" class="Array">', '<tbody>']
    
    if kwargs.get("orient", "v") == "v":
    
        kwargs["orient"] = "h"
        
        for i in range(0, n):
        
            # Try to format the contents of this element.
            try:
            
                value = __formatters__[a[i]](a[i], **kwargs)
            
            except KeyError:
            
                value = encode(str(a[i]))
            
            output.append("<tr>\n<td>%s</td>\n</tr>\n" % value)
    
    else:
    
        kwargs["orient"] = "v"
        
        output.append("<tr>")
        
        for i in range(0, n):
        
            # Try to format the contents of this element.
            try:
            
                value = __formatters__[a[i]](a[i], **kwargs)
            
            except KeyError:
            
                value = encode(str(a[i]))
            
            output.append("<td>%s</td>\n" % value)
        
        output.append("</tr>")
    
    output = output + ["</tbody>", "</table>"]
    
    return "\n".join(output)

__formatters__[Numeric.ArrayType] = format_array
